==> aws-cdk-lib-2.225.0-sources.jar: software/amazon/awscdk/interfaces/bedrockagentcore/BrowserCustomReference.java <==
package software.amazon.awscdk.interfaces.bedrockagentcore;

/**
 * A reference to a BrowserCustom resource.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.interfaces.bedrockagentcore.*;
 * BrowserCustomReference browserCustomReference = BrowserCustomReference.builder()
 *         .browserId("browserId")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.119.0 (build 1634eac)", date = "2025-11-17T14:41:03.004Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.interfaces.aws_bedrockagentcore.BrowserCustomReference")
@software.amazon.jsii.Jsii.Proxy(BrowserCustomReference.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface BrowserCustomReference extends software.amazon.jsii.JsiiSerializable {

    /**
     * The BrowserId of the BrowserCustom resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getBrowserId();

    /**
     * @return a {@link Builder} of {@link BrowserCustomReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link BrowserCustomReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<BrowserCustomReference> {
        java.lang.String browserId;

        /**
         * Sets the value of {@link BrowserCustomReference#getBrowserId}
         * @param browserId The BrowserId of the BrowserCustom resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder browserId(java.lang.String browserId) {
            this.browserId = browserId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link BrowserCustomReference}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public BrowserCustomReference build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link BrowserCustomReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements BrowserCustomReference {
        private final java.lang.String browserId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.browserId = software.amazon.jsii.Kernel.get(this, "browserId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.browserId = java.util.Objects.requireNonNull(builder.browserId, "browserId is required");
        }

        @Override
        public final java.lang.String getBrowserId() {
            return this.browserId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("browserId", om.valueToTree(this.getBrowserId()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.interfaces.aws_bedrockagentcore.BrowserCustomReference"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            BrowserCustomReference.Jsii$Proxy that = (BrowserCustomReference.Jsii$Proxy) o;

            return this.browserId.equals(that.browserId);
        }

        @Override
        public final int hashCode() {
            int result = this.browserId.hashCode();
            return result;
        }
    }
}

==> aws-cdk-lib-2.231.0-sources.jar: software/amazon/awscdk/interfaces/bedrockagentcore/BrowserCustomReference.java <==
package software.amazon.awscdk.interfaces.bedrockagentcore;

/**
 * A reference to a BrowserCustom resource.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.interfaces.bedrockagentcore.*;
 * BrowserCustomReference browserCustomReference = BrowserCustomReference.builder()
 *         .browserArn("browserArn")
 *         .browserId("browserId")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.119.0 (build 1634eac)", date = "2025-12-01T16:02:32.155Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.interfaces.aws_bedrockagentcore.BrowserCustomReference")
@software.amazon.jsii.Jsii.Proxy(BrowserCustomReference.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface BrowserCustomReference extends software.amazon.jsii.JsiiSerializable {

    /**
     * The ARN of the BrowserCustom resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getBrowserArn();

    /**
     * The BrowserId of the BrowserCustom resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getBrowserId();

    /**
     * @return a {@link Builder} of {@link BrowserCustomReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link BrowserCustomReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<BrowserCustomReference> {
        java.lang.String browserArn;
        java.lang.String browserId;

        /**
         * Sets the value of {@link BrowserCustomReference#getBrowserArn}
         * @param browserArn The ARN of the BrowserCustom resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder browserArn(java.lang.String browserArn) {
            this.browserArn = browserArn;
            return this;
        }

        /**
         * Sets the value of {@link BrowserCustomReference#getBrowserId}
         * @param browserId The BrowserId of the BrowserCustom resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder browserId(java.lang.String browserId) {
            this.browserId = browserId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link BrowserCustomReference}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public BrowserCustomReference build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link BrowserCustomReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements BrowserCustomReference {
        private final java.lang.String browserArn;
        private final java.lang.String browserId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.browserArn = software.amazon.jsii.Kernel.get(this, "browserArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.browserId = software.amazon.jsii.Kernel.get(this, "browserId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.browserArn = java.util.Objects.requireNonNull(builder.browserArn, "browserArn is required");
            this.browserId = java.util.Objects.requireNonNull(builder.browserId, "browserId is required");
        }

        @Override
        public final java.lang.String getBrowserArn() {
            return this.browserArn;
        }

        @Override
        public final java.lang.String getBrowserId() {
            return this.browserId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("browserArn", om.valueToTree(this.getBrowserArn()));
            data.set("browserId", om.valueToTree(this.getBrowserId()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.interfaces.aws_bedrockagentcore.BrowserCustomReference"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            BrowserCustomReference.Jsii$Proxy that = (BrowserCustomReference.Jsii$Proxy) o;

            if (!browserArn.equals(that.browserArn)) return false;
            return this.browserId.equals(that.browserId);
        }

        @Override
        public final int hashCode() {
            int result = this.browserArn.hashCode();
            result = 31 * result + (this.browserId.hashCode());
            return result;
        }
    }
}
